@@ -746,12 +746,13 @@ wnck_window_is_sticky                 (WnckWindow *window)
 }
 
 void
-wnck_window_close (WnckWindow *window)
+wnck_window_close (WnckWindow *window,
+		   guint32     timestamp)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
   _wnck_close (WNCK_SCREEN_XSCREEN (window->priv->screen),
-	       window->priv->xwindow);
+	       window->priv->xwindow, timestamp);
 }
 
 void
